;; Generated package description from websocket.el  -*- no-byte-compile: t -*-
(define-package "websocket" "1.14.0.20230304.231043" "Emacs WebSocket client and server" '((cl-lib "0.5")) :commit "1a08093b122d8cf20366a1cba5faddf7a53d08ed" :authors '(("Andrew Hyatt" . "ahyatt@gmail.com")) :maintainer '("Andrew Hyatt" . "ahyatt@gmail.com") :keywords '("communication" "websocket" "server") :url "https://github.com/ahyatt/emacs-websocket")
